==> u61-0.2.2.tar.gz: u61-0.2.2/src/editnumber.h <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   editnumber.h
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: A menu item which allows the user to type a number.
 *              this is different from the number item where the number
 *              is chosen with the arrow keys.
 *              Here, one just type the text as if it were a "edit" item
 */



#ifndef INC_U61_EDITNUMBER
#define INC_U61_EDITNUMBER

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include <ClanLib/core.h>
#include "edit.h"
#include "const.h"

/*---------------------------------------------------------------------------
 classes
 ---------------------------------------------------------------------------*/

class U61_EditNumber: public U61_Edit
{
public:
    U61_EditNumber(char *label, int *val, int min_val, int max_val);
   
    virtual bool action(int key); 
    virtual void update();

protected:
    char *name;
   
    int *number_value;
    int min_value;
    int max_value;
};

#endif

==> u61-1.1.0.tar.gz: u61-1.1.0/src/editnumber.h <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000-2003 Christian Mauduit (ufoot@ufoot.org)              *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on Savannah (http://savannah.gnu.org)     *
 ****************************************************************************/

/*
 * file name:   editnumber.h
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: A menu item which allows the user to type a number.
 *              this is different from the number item where the number
 *              is chosen with the arrow keys.
 *              Here, one just type the text as if it were a "edit" item
 */



#ifndef U61_INC_EDITNUMBER
#define U61_INC_EDITNUMBER

/*---------------------------------------------------------------------------
  includes
  ---------------------------------------------------------------------------*/

#include <ClanLib/core.h>
#include "edit.h"
#include "const.h"

/*---------------------------------------------------------------------------
  classes
  ---------------------------------------------------------------------------*/

class U61_EditNumber: public U61_Edit
{
 public:
  U61_EditNumber(char *label, int *val, int min_val, int max_val);
   
  virtual bool action(int key); 
  virtual bool check_value();

 protected:
  char *name;
   
  int *number_value;
  int min_value;
  int max_value;
};

#endif
